Log message:
[[[
Fix an inappropriate function name in update_tests.py.
This was fixed by kfogel within a large change committed as r6173,
but lost when that change was reverted in r6177.
* subversion/tests/clients/cmdline/update_tests.py
(update_to_resolve_text_conflicts): Replaces
update_to_revert_text_conflicts.
(test_list): Adjust.
]]]
- Julian
Index: subversion/tests/clients/cmdline/update_tests.py
===================================================================
--- subversion/tests/clients/cmdline/update_tests.py (revision 6580)
+++ subversion/tests/clients/cmdline/update_tests.py (working copy)
@@ -522,7 +522,7 @@
#----------------------------------------------------------------------
# Helper for update_to_revert_text_conflicts() test -- a singleton handler.
def detect_conflict_files(node, extra_files):
"""NODE has been discovered an extra file on disk. Verify that it
matches one of the regular expressions in the EXTRA_FILES list. If
@@ -538,7 +538,7 @@
print "Found unexpected disk object:", node.name
raise svntest.main.SVNTreeUnequal
-def update_to_revert_text_conflicts(sbox):
+def update_to_resolve_text_conflicts(sbox):
"delete files and update to resolve text conflicts"
if sbox.build():
@@ -1238,7 +1238,7 @@
update_ignores_added,
update_to_rev_zero,
receive_overlapping_same_change,
- update_to_revert_text_conflicts,
+ update_to_resolve_text_conflicts,
update_delete_modified_files,
update_after_add_rm_deleted,
update_missing,
---------------------------------------------------------------------
To unsubscribe, e-mail: dev-unsubscribe@subversion.tigris.org
For additional commands, e-mail: dev-help@subversion.tigris.org
Received on Fri Jul 25 23:37:41 2003
@@ -522,7 +522,7 @@
#----------------------------------------------------------------------
-# Helper for update_to_revert_text_conflicts() test -- a singleton handler.
+# Helper for update_to_resolve_text_conflicts() test -- a singleton handler.
def detect_conflict_files(node, extra_files):
"""NODE has been discovered an extra file on disk. Verify that it